/*
 * telepathy-logger.h - Headers for telepathy-logger
 *
 * Copyright (C) 2010 Collabora Ltd. <http://www.collabora.co.uk/>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __TELEPATHY_LOGGER_H__
#define __TELEPATHY_LOGGER_H__

#include <telepathy-logger/entity.h>
#include <telepathy-logger/text-event.h>
#include <telepathy-logger/call-event.h>
#include <telepathy-logger/event.h>
#include <telepathy-logger/log-manager.h>
#include <telepathy-logger/log-walker.h>

#endif
